@@ -171,23 +171,27 @@ class NamesUrlsMixin(Model):
             return '#'
 
     def get_activity_stream_url(self) -> str:
-        # Use parent model to generate URL for proxy models activity stream
-        if self._meta.proxy:
-            parent_model = list(self._meta.parents.keys())[0]
-            model_name = parent_model._meta.model_name
-        else:
-            model_name = self.model_name()
-
         try:
             kwargs = {
                 'app': self.get_app_label(),
-                'model': model_name,
+                'model': self._meta.concrete_model().__class__.__name__.lower(),
                 'cid': self.cid,
             }
             return reverse('frontend:activity_stream_record', kwargs=kwargs)
         except NoReverseMatch:
             return '#'
 
+    def get_activity_stream_model_deletes_url(self) -> str:
+        try:
+            kwargs = {
+                'app': self.get_app_label(),
+                'model': self._meta.concrete_model().__class__.__name__.lower(),
+                'operation': 'delete',
+            }
+            return reverse('frontend:activity_stream_record', kwargs=kwargs)
+        except NoReverseMatch:
+            return '#'
+
     def model_name(self) -> str:
         """
         By default, the model name is used for URL prefixes.
@@ -208,30 +212,34 @@ class NamesUrlsMixin(Model):
             return name.title()
         return ''
 
+    @cached_property
+    def get_url_base_name(self) -> str:
+        return f'{self.get_app_label()}:{self.model_name()}'
+
     def get_list_url_name(self) -> str:
         """For list views where endless pagination means page param will increment"""
         try:
-            reverse(f'{self.get_app_label()}:{self.model_name()}_list')
-            return f'{self.get_app_label()}:{self.model_name()}_list'
+            reverse(f'{self.get_url_base_name}_list')
+            return f'{self.get_url_base_name}_list'
         except NoReverseMatch:
             return '#'
 
     def get_list_url(self) -> str:
         try:
-            return reverse(f'{self.get_app_label()}:{self.model_name()}_list')
+            return reverse(f'{self.get_url_base_name}_list')
         except NoReverseMatch:
             return '#'
 
     def get_create_url(self) -> str:
         try:
-            return reverse(f'{self.get_app_label()}:{self.model_name()}_create')
+            return reverse(f'{self.get_url_base_name}_create')
         except NoReverseMatch:
             return '#'
 
     def get_update_url(self) -> str:
         try:
             return reverse(
-                f'{self.get_app_label()}:{self.model_name()}_update', kwargs={'pk': self.pk}
+                f'{self.get_url_base_name}_update', kwargs={'pk': self.pk}
             )
         except NoReverseMatch:
             return '#'
@@ -239,7 +247,7 @@ class NamesUrlsMixin(Model):
     def get_clone_url(self) -> str:
         try:
             return reverse(
-                f'{self.get_app_label()}:{self.model_name()}_clone', kwargs={'pk': self.pk}
+                f'{self.get_url_base_name}_clone', kwargs={'pk': self.pk}
             )
         except NoReverseMatch:
             return '#'
@@ -247,7 +255,7 @@ class NamesUrlsMixin(Model):
     def get_delete_url(self) -> str:
         try:
             return reverse(
-                f'{self.get_app_label()}:{self.model_name()}_delete', kwargs={'pk': self.pk}
+                f'{self.get_url_base_name}_delete', kwargs={'pk': self.pk}
             )
         except NoReverseMatch:
             return '#'
@@ -255,7 +263,7 @@ class NamesUrlsMixin(Model):
     def get_toggle_url(self) -> str:
         try:
             return reverse(
-                f'{self.get_app_label()}:{self.model_name()}_toggle', kwargs={'pk': self.pk}
+                f'{self.get_url_base_name}_toggle', kwargs={'pk': self.pk}
             )
         except NoReverseMatch:
             return '#'
