@@ -314,6 +314,30 @@ class LCDataTablesListBase(
             return str(model_obj._meta.verbose_name_plural).title()  # type: ignore[union-attr]
         return ''
 
+    def show_record_activity_stream_btn(self) -> bool:
+        """
+        The Activity Stream button is to display the stream
+        for a specific model, which doesn't apply in list view.
+        """
+        return False
+
+    def show_record_activity_stream_deletes_btn(self) -> bool:
+
+        if not self.concord_event_tracked_model():
+            return False
+
+        if not self.request.user.is_authenticated:
+            return False
+
+        try:
+            return self.request.user.has_perm(settings.SHOW_ACTIVITY_STREAM_PERM)
+        except AttributeError:
+            logger.info('SHOW_ACTIVITY_STREAM_PERM setting is not defined')
+            return False
+
+    def show_context_menu_btn(self) -> bool:
+        return self.show_record_activity_stream_deletes_btn()
+
     def table_filters(self) -> str:
         return ''
 
@@ -537,6 +561,10 @@ class LCDetailViewBase(
     def show_sync_menu_btn(self) -> bool:
         return False
 
+    # -----------------------------------------------------
+    def show_context_menu_btn(self) -> bool:
+        return self.show_record_activity_stream_btn()
+
     def get(self, request: LCHttpRequest, *args: Any, **kwargs: Any) -> HttpResponse:
         # call superclass method first, so self.object is defined
         # for use in get_warning_message
