@@ -625,6 +625,13 @@ class ObjectURLs(CrumbTrail):
         except AttributeError:
             return BaseModelObject
 
+    def concord_event_tracked_model(self) -> bool:
+        """
+        Model is tracked by Concord event management
+        framework (based on pghistory)
+        """
+        return hasattr(self.model_object(), 'pgh_event_model')
+
     def model_name(self) -> str:
         try:
             return self.model_object().model_name()  # type: ignore[call-arg]
@@ -753,6 +760,9 @@ class ObjectURLs(CrumbTrail):
         permissions. Customize on subclasses as necessary. Keep in mind that any
         refinement of logic here needs to be supported by the View Permission!
         """
+        if not self.concord_event_tracked_model():
+            return False
+
         if not self.request.user.is_authenticated:
             return False
 
@@ -762,6 +772,12 @@ class ObjectURLs(CrumbTrail):
             logger.info('SHOW_ACTIVITY_STREAM_PERM setting is not defined')
             return False
 
+    def show_record_activity_stream_deletes_btn(self) -> bool:
+        """
+        Should only be activated on list views.
+        """
+        return False
+
     def show_pattern_activity_stream_btn(self) -> bool:
         return self.show_record_activity_stream_btn()
 
@@ -804,6 +820,11 @@ class ObjectURLs(CrumbTrail):
         """
         return self.show_delete_btn()
 
+    # -----------------------------------------------------
+    def show_context_menu_btn(self) -> bool:
+        """Show context dropdown menu in the title panel on detail and list pages"""
+        return False
+
     # -----------------------------------------------------
     def show_sync_menu_btn(self) -> bool:
         """Show sync dropdown menu in the title panel on detail pages"""
@@ -823,8 +844,10 @@ class ObjectURLs(CrumbTrail):
             show_update_btn=self.show_update_btn(),
             show_pattern_activity_stream_btn=self.show_pattern_activity_stream_btn(),
             show_record_activity_stream_btn=self.show_record_activity_stream_btn(),
+            show_record_activity_stream_deletes_btn=self.show_record_activity_stream_deletes_btn(),
             show_pattern_update_btn=self.show_pattern_update_btn(),
             show_pattern_delete_btn=self.show_pattern_delete_btn(),
+            show_context_menu_btn=self.show_context_menu_btn(),
             show_sync_menu_btn=self.show_sync_menu_btn(),
             url_name=self.url_name,  # noqa
             view_css_icon=self.css_icon,
